__author__ = "Lukas Leufen"
__date__ = '2019-11-14'


import logging
import argparse

from src.modules.experiment_setup import ExperimentSetup
from src.modules.run_environment import RunEnvironment
from src.modules.pre_processing import PreProcessing
from src.modules.model_setup import ModelSetup
from src.modules.modules import Training, PostProcessing


def main(parser_args):

    with RunEnvironment():
        ExperimentSetup(parser_args, stations=['DEBW107', 'DEBY081', 'DEBW013', 'DEBW076', 'DEBW087', 'DEBW001'],
                        station_type='background')
        PreProcessing()

        ModelSetup()

        Training()

        PostProcessing()


if __name__ == "__main__":

    formatter = '%(asctime)s - %(levelname)s: %(message)s  [%(filename)s:%(funcName)s:%(lineno)s]'
    logging.basicConfig(format=formatter, level=logging.INFO)

    parser = argparse.ArgumentParser()
    parser.add_argument('--experiment_date', metavar='--exp_date', type=str, nargs=1, default=None,
                        help="set experiment date as string")
    args = parser.parse_args()

    main(args)
